/*
 *  libpipi       Proper image processing implementation library
 *  Copyright (c) 2004-2008 Sam Hocevar <sam@zoy.org>
 *                All Rights Reserved
 *
 *  $Id$
 *
 *  This library is free software. It comes without any warranty, to
 *  the extent permitted by applicable law. You can redistribute it
 *  and/or modify it under the terms of the Do What The Fuck You Want
 *  To Public License, Version 2, as published by Sam Hocevar. See
 *  http://sam.zoy.org/wtfpl/COPYING for more details.
 */

/*
 * imlib.c: ImLib I/O functions
 */

#include "config.h"
#include "common.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <Imlib2.h>

#include "pipi.h"
#include "pipi_internals.h"

pipi_image_t *pipi_load_imlib2(const char *name)
{
    pipi_image_t *img;
    Imlib_Image priv = imlib_load_image(name);

    if(!priv)
        return NULL;

    img = (pipi_image_t *)malloc(sizeof(pipi_image_t));
    imlib_context_set_image(priv);
    img->width = imlib_image_get_width();
    img->height = imlib_image_get_height();
    img->pitch = 4 * imlib_image_get_width();
    img->channels = 4;
    img->pixels = (char *)imlib_image_get_data();
    img->priv = (void *)priv;

    return img;
}

pipi_image_t *pipi_new_imlib2(int width, int height)
{
    pipi_image_t *img;
    Imlib_Image priv = imlib_create_image(width, height);

    if(!priv)
        return NULL;

    img = (pipi_image_t *)malloc(sizeof(pipi_image_t));
    imlib_context_set_image(priv);
    img->width = imlib_image_get_width();
    img->height = imlib_image_get_height();
    img->pitch = 4 * imlib_image_get_width();
    img->channels = 4;
    img->pixels = (char *)imlib_image_get_data();
    img->priv = (void *)priv;

    return img;
}

void pipi_free_imlib2(pipi_image_t *img)
{
    imlib_context_set_image(img->priv);
    imlib_free_image();

    free(img);
}

void pipi_save_imlib2(pipi_image_t *img, const char *name)
{
    imlib_context_set_image(img->priv);
    imlib_save_image(name);
}

